@@ -1,5 +1,15 @@
 var NAVTREEINDEX17 =
 {
+"structpw__client__endpoint__events.html#a02d8f4d9cd9f898d3109a64f7afd81e1":[10,7,4,6,4],
+"structpw__client__endpoint__events.html#a12f427748eebbfd39cdc4f75a9db57ed":[10,7,4,6,1],
+"structpw__client__endpoint__events.html#a43e06e14ba4461922bfce4c3c98c13f1":[10,7,4,6,3],
+"structpw__client__endpoint__events.html#a45e7bb70eb2b24c33aad0c82dcf001b6":[10,7,4,6,2],
+"structpw__client__endpoint__events.html#afab781a09b218afdc2c9ffb54502be5e":[10,7,4,6,0],
+"structpw__client__endpoint__methods.html":[10,7,4,7],
+"structpw__client__endpoint__methods.html#a283f6ec14d1a3ff9b0b0aa213b2ea850":[10,7,4,7,1],
+"structpw__client__endpoint__methods.html#a58fe2e1f1524cf0f22dda84f7f9c33e0":[10,7,4,7,0],
+"structpw__client__events.html":[10,4,3,2],
+"structpw__client__events.html#a0ceb2ae8884ca4a30bae720198410075":[10,4,3,2,0],
 "structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254":[10,4,3,2,1],
 "structpw__client__events.html#af685647fe57d1a9dba2a0d89d32aae39":[10,4,3,2,2],
 "structpw__client__info.html":[10,4,3,1],
@@ -239,15 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__impl__device__events.html#ad9bbb080f7502ba24a6c170461078884":[10,5,2,1,3],
 "structpw__impl__device__events.html#adbb4dbff59d4c076dd28626b2b2de840":[10,5,2,1,0],
 "structpw__impl__device__events.html#aee86b69561fd8e8f0525223ed8685e60":[10,5,2,1,4],
-"structpw__impl__factory.html":[10,5,3,3],
-"structpw__impl__factory__events.html":[10,5,3,1],
-"structpw__impl__factory__events.html#a61bf0bc918867a1315f7c09e870cf297":[10,5,3,1,0],
-"structpw__impl__factory__events.html#a6bb4670f4a96e31d0f1f30d3fc763bc6":[10,5,3,1,3],
-"structpw__impl__factory__events.html#abb0d82e4263cbe36b38aa10eef130ad0":[10,5,3,1,1],
-"structpw__impl__factory__events.html#ae608dbd84c609b5b8a6d7c232e5a569f":[10,5,3,1,2],
-"structpw__impl__factory__implementation.html":[10,5,3,2],
-"structpw__impl__factory__implementation.html#a99eef2345bd7b402f47ad72beb6ebfe7":[10,5,3,2,1],
-"structpw__impl__factory__implementation.html#ab63e939995687efd690f736730021e7f":[10,5,3,2,0],
-"structpw__impl__link.html":[10,5,4,2],
-"structpw__impl__link.html":[10,5,8,3]
+"structpw__impl__factory.html":[10,5,3,3]
 };
